@@ -9,10 +9,10 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.014';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.015';
 }
 
-# ABSTRACT: Zilla your Dists like RSRCHBOY!
+# ABSTRACT: Zilla your distributions like RSRCHBOY!
 
 use Moose;
 use namespace::autoclean;
@@ -23,6 +23,43 @@ with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 use Path::Class;
 
+use Dist::Zilla::PluginBundle::Git                  ( );
+use Dist::Zilla::PluginBundle::Git::CheckFor        ( );
+use Dist::Zilla::Plugin::ArchiveRelease             ( );
+use Dist::Zilla::Plugin::CheckPrereqsIndexed        ( );
+use Dist::Zilla::Plugin::CopyFilesFromBuild         ( );
+use Dist::Zilla::Plugin::ConfirmRelease             ( );
+use Dist::Zilla::Plugin::ConsistentVersionTest      ( );
+use Dist::Zilla::Plugin::EOLTests                   ( );
+use Dist::Zilla::Plugin::ExtraTests                 ( );
+use Dist::Zilla::Plugin::Git::NextVersion           ( );
+use Dist::Zilla::Plugin::GitHub::Meta               ( );
+use Dist::Zilla::Plugin::GitHub::Update             ( );
+use Dist::Zilla::Plugin::HasVersionTests            ( );
+use Dist::Zilla::Plugin::InstallGuide               ( );
+use Dist::Zilla::Plugin::InstallRelease             ( );
+use Dist::Zilla::Plugin::MetaConfig                 ( );
+use Dist::Zilla::Plugin::MetaJSON                   ( );
+use Dist::Zilla::Plugin::MetaYAML                   ( );
+use Dist::Zilla::Plugin::MinimumPerl                ( );
+use Dist::Zilla::Plugin::NoSmartCommentsTests       ( );
+use Dist::Zilla::Plugin::NoTabsTests                ( );
+use Dist::Zilla::Plugin::PodWeaver                  ( );
+use Dist::Zilla::Plugin::PodCoverageTests           ( );
+use Dist::Zilla::Plugin::PodSyntaxTests             ( );
+use Dist::Zilla::Plugin::Prepender                  ( );
+use Dist::Zilla::Plugin::PruneFiles                 ( );
+use Dist::Zilla::Plugin::ReadmeFromPod              ( );
+use Dist::Zilla::Plugin::ReadmeAnyFromPod           ( );
+use Dist::Zilla::Plugin::ReportVersions::Tiny       ( );
+use Dist::Zilla::Plugin::SurgicalPkgVersion         ( );
+use Dist::Zilla::Plugin::TaskWeaver                 ( );
+use Dist::Zilla::Plugin::Test::Compile              ( );
+use Dist::Zilla::Plugin::Test::PodSpelling 2.002001 ( );
+use Dist::Zilla::Plugin::Test::Portability          ( );
+use Dist::Zilla::Plugin::TestRelease                ( );
+use Dist::Zilla::Plugin::UploadToCPAN               ( );
+
 # additional deps
 use Archive::Tar::Wrapper   ( );
 use Test::NoSmartComments   ( );
@@ -31,50 +68,13 @@ use Test::Pod               ( );
 use Test::Pod::Content      ( );
 use Pod::Coverage::TrustPod ( );
 
-use Dist::Zilla::PluginBundle::Git;
-
-#use Dist::Zilla::Plugin::Authority;
-use Dist::Zilla::Plugin::ArchiveRelease;
-use Dist::Zilla::Plugin::CheckPrereqsIndexed;
-use Dist::Zilla::Plugin::CopyFilesFromBuild;
-use Dist::Zilla::Plugin::ConfirmRelease;
-use Dist::Zilla::Plugin::ConsistentVersionTest;
-use Dist::Zilla::Plugin::EOLTests;
-use Dist::Zilla::Plugin::ExtraTests;
-use Dist::Zilla::Plugin::Git::NextVersion;
-use Dist::Zilla::Plugin::GitHub::Meta;
-use Dist::Zilla::Plugin::GitHub::Update;
-use Dist::Zilla::Plugin::HasVersionTests;
-use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::InstallRelease;
-use Dist::Zilla::Plugin::MetaConfig;
-use Dist::Zilla::Plugin::MetaJSON;
-use Dist::Zilla::Plugin::MetaYAML;
-use Dist::Zilla::Plugin::MinimumPerl;
-use Dist::Zilla::Plugin::NoSmartCommentsTests;
-use Dist::Zilla::Plugin::NoTabsTests;
-use Dist::Zilla::Plugin::PodWeaver;
-use Dist::Zilla::Plugin::PodCoverageTests;
-use Dist::Zilla::Plugin::PodSyntaxTests;
-use Dist::Zilla::Plugin::Prepender;
-use Dist::Zilla::Plugin::PruneFiles;
-use Dist::Zilla::Plugin::ReadmeFromPod;
-use Dist::Zilla::Plugin::ReadmeAnyFromPod;
-use Dist::Zilla::Plugin::ReportVersions::Tiny;
-use Dist::Zilla::Plugin::SurgicalPkgVersion;
-use Dist::Zilla::Plugin::TaskWeaver;
-use Dist::Zilla::Plugin::Test::Compile;
-use Dist::Zilla::Plugin::Test::Portability;
-use Dist::Zilla::Plugin::TestRelease;
-use Dist::Zilla::Plugin::UploadToCPAN;
-
 has is_task    => (is => 'lazy', isa => 'Bool');
 has is_app     => (is => 'lazy', isa => 'Bool');
 has is_private => (is => 'lazy', isa => 'Bool');
 
-sub _build_is_task    { $_[0]->payload->{task}    }
+sub _build_is_task    { $_[0]->payload->{task}                             }
 sub _build_is_app     { $_[0]->payload->{cat_app} || $_[0]->payload->{app} }
-sub _build_is_private { $_[0]->payload->{private} }
+sub _build_is_private { $_[0]->payload->{private}                          }
 
 sub configure {
     my $self = shift @_;
@@ -111,6 +111,8 @@ sub configure {
         { version_regexp => '^(\d.\d+)$' },
     ]);
 
+    $self->add_bundle('Git::CheckFor');
+
     $self->add_plugins(
         qw{
             GatherDir
@@ -126,7 +128,18 @@ sub configure {
         },
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
+        [ 'Test::PodSpelling' => {
+            stopwords => [ qw{
+                AFAICT
+                ABEND
+                RSRCHBOY
+                RSRCHBOY's
+                ini
+                subclasses
+            } ] },
+        ],
         qw{
+
             ConsistentVersionTest
             PodCoverageTests
             PodSyntaxTests
@@ -187,13 +200,20 @@ __PACKAGE__->meta->make_immutable;
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your Dists like RSRCHBOY!
+Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-version 0.014
+This document describes 0.015 of Dist::Zilla::PluginBundle::RSRCHBOY - released February 06, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+
+=head1 SYNOPSIS
+
+    # in your dist.ini...
+    [@RSRCHBOY]
 
 =head1 DESCRIPTION
 
@@ -203,10 +223,19 @@ this being too terribly consistent/sane until the version gets to 1.
 
 =for Pod::Coverage configure
 
-=head1 SYNOPIS
+=head1 SOURCE
 
-    # in your dist.ini...
-    [@RSRCHBOY]
+The development version is on github at L<http://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY>
+and may be cloned from L<git://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
